@@ -80,8 +80,10 @@ class NelsonAalenFitter(object):
         return df
 
     def _variance_f_smooth(self, population, deaths):
+        """TODO: speed this up"""
         df = pd.DataFrame( {'N':population, 'd':deaths})
-        return df.apply( lambda N_d: np.sum([1./(N_d[0]-i)**2 for i in range(int(N_d[1]))]), axis=1 )
+        return df.apply( lambda N_d: np.sum( [1./(N_d[0]-i)**2 for i in range(int(N_d[1]))]), axis=1 )
+        #return df.apply( lambda (N,d): np.sum([1./(N-i)**2 for i in xrange(int(d))]), axis=1 )
 
     def _variance_f_discrete(self, population, deaths):
         return 1.*(population-deaths)*deaths/population**3
@@ -89,6 +91,7 @@ class NelsonAalenFitter(object):
     def _additive_f_smooth(self, population, deaths):
         df = pd.DataFrame( {'N':population, 'd':deaths})
         return df.apply( lambda N_d: np.sum([1./(N_d[0]-i) for i in range(int(N_d[1]))]), axis=1 )
+        #return df.apply( lambda (N,d): np.sum([1./(N-i) for i in xrange(int(d))]), axis=1 )
 
     def _additive_f_discrete(self, population, deaths):
        return (1.*deaths/population).replace([np.inf],0)
